#
# spec file for package python-jupyter-ydoc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jupyter-ydoc
Version:        3.1.0
Release:        1.1
Summary:        Document structures for collaborative editing using Ypy
License:        BSD-3-Clause
URL:            https://github.com/jupyter-server/jupyter_ydoc
# Versioned sdist
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter-ydoc/jupyter_ydoc-%{version}.tar.gz
# unversioned, but tests
Source1:        https://github.com/jupyter-server/jupyter_ydoc/archive/refs/tags/v%{version}.tar.gz#/jupyter_ydoc-%{version}-gh.tar.gz
Source2:        node_modules.tar.xz
# Execute this on every package update. See comments in the script.
Source3:        create_node_modules.sh
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatch_nodejs_version}
BuildRequires:  %{python_module hatchling >= 1.10}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-importlib-metadata >= 3.6 if python-base < 3.10)
Requires:       (python-pycrdt >= 0.10.1 with python-pycrdt < 0.13)
Provides:       python-jupyter_ydoc = %{version}-%{release}
BuildArch:      noarch
# SECTION test
BuildRequires:  %{python_module importlib-metadata >= 3.6 if %python-base < 3.10}
BuildRequires:  %{python_module httpx-ws >= 0.5.2}
BuildRequires:  %{python_module hypercorn >= 0.16}
BuildRequires:  %{python_module pycrdt >= 0.10.1 with %python-pycrdt < 0.13}
BuildRequires:  %{python_module pycrdt-websocket >= 0.15.0 with %python-pycrdt-websocket < 0.16}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  nodejs
BuildRequires:  procps
BuildRequires:  yarn
# /SECTION
%python_subpackages

%description
Ypy-based data structures for various documents used in the Jupyter ecosystem.
Built-in documents include:
  - `YBlob`: a generic immutable binary document.
  - `YUnicode`: a generic UTF8-encoded text document (`YFile` is an alias to `YUnicode`).
  - `YNotebook`: a Jupyter notebook document.

%prep
%setup -q -n jupyter_ydoc-%{version} -b1 -a2

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/jupyter-server/jupyter_ydoc/issues/168
%pytest

%files %{python_files}
%{python_sitelib}/jupyter_ydoc
%{python_sitelib}/jupyter_ydoc-%{version}.dist-info

%changelog
* Wed Jul  2 2025 Ben Greiner <code@bnavigator.de>
- Update to 3.1.0
  * Add clearOutputs() method to ISharedCodeCell #330 (@Darshan808)
* Thu Jun 19 2025 Daniel Garcia <daniel.garcia@suse.com>
- Update to 3.0.5 (CVE-2025-5889, bsc#1244347):
  * Bump ip from 2.0.0 to 2.0.1 #325 (@dlqqq)
  3.0.4:
  * Set undoManager in constructor for cells in notebook #321 (@krassowski)
  * Fix including Typescript source in package #312 (@fcollonval)
  * Bump apache/skywalking-eyes from 0.4.0 to 0.7.0 #310 (@dependabot)
* Wed Jan 29 2025 Ben Greiner <code@bnavigator.de>
- Update to 3.0.3
  * Fix missing nbformat version #304 (@fcollonval)
  * Increase pycrdt compatible version range #307 (@davidbrochart)
  * Fix stream output #294 (@davidbrochart)
  * Fix tests #288 (@davidbrochart)
* Thu Dec  5 2024 Nico Krapp <nico.krapp@suse.com>
- refresh node modules
  * update cross-spawn module to 7.0.6 - CVE-2024-21538 (bsc#1233852)
* Mon Nov  4 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.0.0
  [#]# Enhancements made
  * Add the awareness in the shared document interface #282
    (@brichet)
  * Doc awareness #277 (@brichet)
  * Improve notebook output stream initialization #275
    (@davidbrochart)
  * Add YDocument source getter/setter #273 (@davidbrochart)
  * Allow empty notebook #266 (@davidbrochart)
  * Add streamOutputChange attribute to cell change object #264
    (@davidbrochart)
  * Add hash property with setter and getter #262 (@krassowski)
  * Expose execution_state in the JS package #259 (@krassowski)
  * Add undo_manager to Y documents #248 (@davidbrochart)
  * Add optional origin to transaction, filter out 'modeldb' origin
    [#246] (@davidbrochart)
  * Add appendStreamOutput and removeStreamOutput methods #241
    (@davidbrochart)
  * Update python>=3.8, pycrdt>=0.8.11, pre-commit, README #217
    (@davidbrochart)
  * Store YBlob as bytes, not base64-encoded string #209
    (@davidbrochart)
  * Change notebook code cell stream output schema #201
    (@davidbrochart)
  * Add cell execution_state #197 (@davidbrochart)
  [#]# Bugs fixed
  * Fix attachments change attribute assignment #260 (@krassowski)
  * Fix createOutputs, rename 'modeldb' origin to 'silent-change'
    [#254] (@davidbrochart)
  [#]# Maintenance and upkeep improvements
  * Revert #266 #280 (@davidbrochart)
  * Improve notebook output stream initialization #275
    (@davidbrochart)
  * Fix dict type for python 3.8 #253 (@davidbrochart)
  * Bump toshimaru/auto-author-assign from 2.1.0 to 2.1.1 #247
    (@dependabot)
  * Revert publish 3.0.0a0 (9c87cfd) #245 (@davidbrochart)
  * Update releaser workflows #244 (@jtpio)
  * Bump notebook version 1.0.0 -> 2.0.0 #236 (@davidbrochart)
  * Fix subscription type, update pycrdt>=0.8.16 #222
    (@davidbrochart)
  * Update python>=3.8, pycrdt>=0.8.11, pre-commit, README #217
    (@davidbrochart)
  * Bump pre-commit/action from 3.0.0 to 3.0.1 #215 (@dependabot)
  * Remove mention to y_py in docs #214 (@martinRenou)
  * Bump toshimaru/auto-author-assign from 2.0.1 to 2.1.0 #212
    (@dependabot)
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.1.1
  * Fix dict type for python 3.8 #252 (@davidbrochart)
  * Add undo_manager to Y documents (#248) #251 (@davidbrochart)
* Mon Jan 22 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * Update pycrdt v0.8 #208 (@davidbrochart)
- Release 2.0.0
  * Use pycrdt instead of y-py #194 (@davidbrochart)
- Ignore that pycrdt is still in incubation phase
  gh#jupyter-server/jupyter_ydoc#211
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Disable tests for jupyter-collaboration and ypy-websocket
  update gh#jupyter-server/jupyter_ydoc#211
* Sat Oct  7 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.1.1
  * Fix joining of source when source is an array of strings #186
    (@jtpio)
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.1.0
  * Add source to dist for sourcemaps #182 (@vidartf)
  * Create awareness interface #171 (@hbcarlos)
* Tue Jun 13 2023 Ben Greiner <code@bnavigator.de>
- Kill nodejs in between pytest runs
  gh#jupyter-server/jupyter_ydoc#168
* Sun Jun 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.0.2
  * Trust the default cell #161 (@krassowski)
- Releases 1.0.0, 1.0.1
  * Fix metadata issue #158 (@hbcarlos)
  * Add py.typed #152 (@davidbrochart)
  * Add model version #139 (@davidbrochart)
- Release 0.3.x
  * Fix notebook undo scope #148 (@fcollonval)
  * Update YDocument constructor #142 (@trungleduc)
  * Add ycells getter #136 (@davidbrochart)
  * Split documents into separate files #135 (@davidbrochart)
  * Fixes handling metadata changes #134 (@hbcarlos)
  * Improves the initialization #124 (@hbcarlos)
  * Improve Python API #122 (@davidbrochart)
  * Notebook metadata #115 (@hbcarlos)
  * Make YDocument a IObservableDisposable #108 (@fcollonval)
  * Add readme to javascript package #106 (@fcollonval)
  * Adds docstring to the python package #101 (@hbcarlos)
  * Import shared model #86 (@fcollonval)
  * Add path document attribute #81 (@davidbrochart)
  * Make YBaseDoc an abstract base class #74 (@davidbrochart)
  * Fixes multiple bugs #131 (@hbcarlos)
  * Fixes metadata #120 (@hbcarlos)
  * Support cell.source is [list, of, string] #112 (@Wh1isper)
  * Removes YMap for attachements #77 (@fcollonval)
  * Drop pkg_resources #59 (@jtpio)
  * Remove factory API #133 (@hbcarlos)
  * Import shared model #86 (@fcollonval)
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.2.4
  * Fix metadata issue #158 (@hbcarlos)
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Downgrade to 0.2.3
  * Rename JS package to @jupyter/ydoc #97 (@jtpio)
- Released as patch release for 0.2 branch
  * jupyterlab 3.6 requires ydoc~=0.2.2
* Sun Feb 12 2023 Ben Greiner <code@bnavigator.de>
- Provide underscore name
* Sun Feb  5 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.3.1
- Required by jupyterlab 3.6
- Provide node_modules.tar.xz generated by create_node_modules.sh
  for the tests. Those modules are not part of the python package
